/**
 * \file  mcasp_audiodc_test.h
 * 
 * \brief The macro definitions and function prototypes for 
 *        configuring mcasp
 *
 */

/*
* Copyright (C) 2017-2018 Texas Instruments Incorporated - http://www.ti.com/
* 
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*
*    Redistributions of source code must retain the above copyright 
*    notice, this list of conditions and the following disclaimer.
*
*    Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the 
*    documentation and/or other materials provided with the   
*    distribution.
*
*    Neither the name of Texas Instruments Incorporated nor the names of
*    its contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
*  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
*  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
*  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
*  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
*  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
*  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
*  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef _MCASP_AUDIODC_TEST_H_
#define _MCASP_AUDIODC_TEST_H_

/* ========================================================================== */
/*                           Macros & Typedefs                                */
/* ========================================================================== */

#define SOC_EDMA3_CC_BASE CSL_DSP_DSP_EDMA_CC_REGS
#define SOC_MCASP_CFG_BASE CSL_MPU_MCASP1_CFG_REGS

#define SOC_MCASP_BASE CSL_MPU_MCASP1_REGS

#define MCASP_TX_FRAME_SYNC_MODE             2u
#define MCASP_TX_FRAME_SYNC_WIDTH            1u
#define MCASP_TX_FRAME_SYNC_POLARITY         2u
#define MCASP_TX_FRAM_SYNC_GENERATION        1u

#define SPI_SPIFMT_DF_SEL 0

#define MCASP_TX_FRAME_SYNC_SELECT          (MCASP_TX_FRAM_SYNC_GENERATION | \
                                             MCASP_TX_FRAME_SYNC_POLARITY)
/*
** Values which are configurable
*/
/* Slot size to send/receive data */
#define SLOT_SIZE                         (32u)

/* Word size to send/receive data. Word size <= Slot size */
#define WORD_SIZE                         (32u)

/* Number of channels, L & R */
#define NUM_I2S_CHANNELS                  (2U)

/* Sampling Rate which will be used by both transmit and receive sections */
#define SAMPLING_RATE                     (48000u)

/* Number of samples to be used per audio buffer */
#define NUM_SAMPLES_PER_AUDIO_BUF         (100u)

/* Number of buffers used per tx/rx */
#define NUM_BUF                           (2U)

/* Number of linked parameter set used per tx/rx */
#define NUM_PAR                           (2U)

/* Specify where the parameter set starting is */
#define PAR_ID_START                      (40U)

/* Number of samples in loop buffer */
#define NUM_SAMPLES_LOOP_BUF              (10U)

/* McASP Serializer 0 for Transmit */
#define MCASP_XSER_TX                   (2U)

/* McASP Serializer 1 for Transmit */
#define MCASP_XSER_RX                   (3U)

/*
** Below Macros are calculated based on the above inputs
*/

#define I2S_SLOTS                         ((1 << NUM_TIMESLOTS_PER_SERIALIZER) - 1)

#define BYTES_PER_SAMPLE                  ((WORD_SIZE >> 3) \
                                           * NUM_I2S_CHANNELS)

#define AUDIO_BUF_SIZE                    (NUM_SAMPLES_PER_AUDIO_BUF \
                                           * BYTES_PER_SAMPLE)

#define EDMA3_CHA_MCASP_RX               (0U)

#define EDMA3_CHA_MCASP_TX               (1U)

#if 0
#define TX_DMA_INT_ENABLE                ((((EDMA_TPCC_OPT_TCC_MASK >> EDMA_TPCC_OPT_TCC_SHIFT ) & EDMA3_CHA_MCASP_TX) << EDMA_TPCC_OPT_TCC_SHIFT) | \
											(1 << EDMA_TPCC_OPT_TCINTEN_SHIFT))

#define RX_DMA_INT_ENABLE                ((((EDMA_TPCC_OPT_TCC_MASK >> EDMA_TPCC_OPT_TCC_SHIFT ) & EDMA3_CHA_MCASP_RX) << EDMA_TPCC_OPT_TCC_SHIFT) | \
											(1 << EDMA_TPCC_OPT_TCINTEN_SHIFT))

#else

#define EDMA3CC_OPT_TCINTEN_SHIFT        (0x00000014u)
	
#define TX_DMA_INT_ENABLE                (EDMA3CC_OPT_TCC_SET(EDMA3_CHA_MCASP_TX) | (1 \
                                               << EDMA3CC_OPT_TCINTEN_SHIFT))
#define RX_DMA_INT_ENABLE                     (EDMA3CC_OPT_TCC_SET(EDMA3_CHA_MCASP_RX) | (1 \
                                               << EDMA3CC_OPT_TCINTEN_SHIFT))
#endif	

#define PAR_RX_START                     (PAR_ID_START)
#define PAR_TX_START                     (PAR_ID_START + NUM_PAR)

#define NUM_TIMESLOTS_PER_SERIALIZER		(2u)

/*
** Below Macros are calculated based on the above inputs
*/
#define NUM_TX_SERIALIZERS                    (NUM_I2S_CHANNELS >> 1)
#define NUM_RX_SERIALIZERS                    (NUM_I2S_CHANNELS >> 1)


#define EDMA3CC_OPT_TCC (0x0003F000u)

#define EDMA3CC_OPT_TCC_SHIFT (0x0000000Cu)

/*
** Definitions which are not configurable
*/
#define EDMA3CC_OPT_DAM 				(0x00000002u)
#define EDMA3CC_OPT_SAM 				(0x00000001u)

#define SIZE_PARAMSET                     (32U)
#define OPT_FIFO_WIDTH                    (0x02 << 8U)

/*
** Definitions which are configurable depending on the core to be used(ARM or DSP)
*/
#ifdef BUILD_DSP
#define EDMA3_CC_REGION		             (1U)
#else
#define EDMA3_CC_REGION		             (0U)
#endif

#define EDMA3_CC_QUEUE                   (0U)


/* Interrupt channels to map in AINTC */
#define INT_CHANNEL_MCASP                     (2u)
#define INT_CHANNEL_EDMACC                    (2u)


/* Audio Loopback test duration in secs */
#define TEST_DURATION_SECS                (15)
/* Total number of samples received during the test */
#define TEST_SAMPLE_COUNT                 ((TEST_DURATION_SECS) * (SAMPLING_RATE))

/* ========================================================================== */
/*                          Function prototypes                              */
/* ========================================================================== */
#endif //_MCASP_AUDIODC_TEST_H_
